##  ReadMe Sheet in Template
The template also includes an additional sheet titled ReadMe. This sheet provides detailed instructions for each column, specifying which columns are read-only, the type of input required, possible values for single-select or multi-select fields, mandatory columns required for a successful import, forbidden characters, and what can and cannot be imported. Be sure to review the ReadMe sheet of the exported Excel file.
![ReadMe Sheet in the Import Template](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27570a527a44101488a4a89bbf460bb0_LowRes.png)
ReadMe Sheet in the Import Template
**Note**
The import function only reads the first sheet of the workbook. Therefore, ensure that the order of the sheets remains unchanged. You may also delete the ReadMe sheet before importing.
